@@ -7,6 +7,7 @@ import boto3
 import shutil
 from zipfile import ZipFile
 from io import BytesIO
+import botocore
 import json
 from .queue import Queue
 import bottle
@@ -227,22 +228,29 @@ class Deployer(object):
 
     def _deploy_tables(self, local):
         for model in self._get_pynamo_models():
+            print(f"Deploying DynamoDB table {model.Meta.table_name}.")
             if local:
                 model.Meta.host = "http://localhost:4566"
 
             try:
                 # TODO: Should probably decide if this is how we want it to work.
                 if model.exists() and local:
+                    print(
+                        f"Deleting existing local DynamoDB table {model.Meta.table_name}."
+                    )
                     model.delete_table()
 
                 model.create_table(wait=True)
             except TableError as e:
-                if local:
-                    print(
-                        "Unable to connect to LocalStack to deploy DynamoDB tables. "
-                        "Have you started LocalStack on your machine ('localstack start')?"
-                    )
-                    exit(1)
+                if isinstance(e.cause, botocore.exceptions.EndpointConnectionError):
+                    if local:
+                        print(
+                            "Unable to connect to LocalStack to deploy DynamoDB tables. "
+                            "Have you started LocalStack on your machine ('localstack start')?"
+                        )
+                        exit(1)
+                    else:
+                        raise e
                 else:
                     raise e
 
